@@ -1,4 +1,4 @@
-""" Parallel hold (PHOLD) model commonly used to benchmark parallel discrete-event simulators :cite:`fujimoto1990performance`.
+""" Parallel hold (PHOLD) model commonly used to benchmark parallel discrete-event simulators
 
 :Author: Arthur Goldberg <Arthur.Goldberg@mssm.edu>
 :Date: 2016-06-10
@@ -24,20 +24,16 @@ def obj_index(obj_name):
     return int(obj_name)
 
 
-def exp_delay():
-    return random.expovariate(1.0)
-
-
 class MessageSentToSelf(de_sim.EventMessage):
-    "A message that's sent to self"
+    " A message that's sent to self "
 
 
 class MessageSentToOtherObject(de_sim.EventMessage):
-    "A message that's sent to another PHold simulation object"
+    " A message that's sent to another PHold simulation object "
 
 
 class InitMsg(de_sim.EventMessage):
-    'initialization message'
+    " Initialization message "
 
 
 MESSAGE_TYPES = [MessageSentToSelf, MessageSentToOtherObject, InitMsg]
@@ -50,10 +46,11 @@ class PholdSimulationObject(de_sim.SimulationObject):
         super().__init__(name)
 
     def init_before_run(self):
-        self.send_event(exp_delay(), self, InitMsg())
+        """ Initialize before a simulation run; called by the simulator """
+        self.send_event(random.expovariate(1.0), self, InitMsg())
 
     def handle_simulation_event(self, event):
-        """Handle a single simulation event."""
+        """ Handle a simulation event """
         # schedule event
         if random.random() < self.args.frac_self_events or self.args.num_phold_procs == 1:
             receiver = self
@@ -73,15 +70,13 @@ class PholdSimulationObject(de_sim.SimulationObject):
             message = MessageSentToSelf
         else:
             message = MessageSentToOtherObject
-        self.send_event(exp_delay(), receiver, message())
-
-    def get_state(self):
-        return str(self.args)
+        self.send_event(random.expovariate(1.0), receiver, message())
 
     def log_debug_msg(self, msg):
         log = logs.get_log('de_sim.debug.example.console')
         log.debug(msg, sim_time=self.time)
 
+    # declare that any event containing an event message in `MESSAGE_TYPES` is handled by `handle_simulation_event`
     event_handlers = [(sim_msg_type, 'handle_simulation_event') for sim_msg_type in MESSAGE_TYPES]
 
     # register the message types sent
@@ -98,7 +93,7 @@ class RunPhold(object):
             cli_args (:obj:`list`): command line arguments
 
         Returns:
-            :obj:`argparse.Namespace`: parsed command line arguements
+            :obj:`argparse.Namespace`: parsed command line arguments
         """
         parser = argparse.ArgumentParser(description="Run PHOLD simulation. "
                                          "Each PHOLD event either schedules an event for 'self' or for some other randomly selected LP, "
@@ -110,7 +105,7 @@ class RunPhold(object):
                                          "SIGSIM-PADS '13. Montreal: Association for Computing Machinery; 2013. p. 327-36. ")
         parser.add_argument('num_phold_procs', type=int, help="Number of PHOLD processes to run")
         parser.add_argument('frac_self_events', type=float, help="Fraction of events sent to self")
-        parser.add_argument('time_max', type=float, help="End time for the simulation")
+        parser.add_argument('max_time', type=float, help="End time for the simulation")
         parser.add_argument('--seed', '-s', type=int, help='Random number seed')
         args = parser.parse_args(cli_args)
 
@@ -137,7 +132,7 @@ class RunPhold(object):
 
         # run the simulation
         simulator.initialize()
-        event_num = simulator.simulate(args.time_max).num_events
+        event_num = simulator.simulate(args.max_time).num_events
         sys.stderr.write("Executed {} events.\n".format(event_num))
         return(event_num)
 
