@@ -9,10 +9,10 @@
 import enum
 import numpy
 
-import de_sim
 from de_sim.checkpoint import AccessCheckpoints, Checkpoint
 from de_sim.simulation_checkpoint_object import (AccessStateObjectInterface,
                                                  CheckpointSimulationObject)
+import de_sim
 
 
 class SusceptibleToInfectious(de_sim.EventMessage):
@@ -94,7 +94,7 @@ class SIR(de_sim.SimulationObject):
         """ Handle a susceptible to infectious event
 
         Args:
-            event (:obj:`de_sim.Event`): simulation event; not used
+            event (:obj:`~de_sim.event.Event`): simulation event; not used
         """
         self.s -= 1
         self.i += 1
@@ -104,7 +104,7 @@ class SIR(de_sim.SimulationObject):
         """ Handle an infectious to recovered event
 
         Args:
-            event (:obj:`de_sim.Event`): simulation event; not used
+            event (:obj:`~de_sim.event.Event`): simulation event; not used
         """
         self.i -= 1
         self.schedule_next_event()
@@ -128,8 +128,8 @@ MESSAGE_TYPES = [TransitionMessage]
 class StateTransitionType(enum.Enum):
     """ State transition types
     """
-    s_to_i = enum.auto()    # Transition from Susceptible to Infectious
-    i_to_r = enum.auto()    # Transition from Infectious to Recovered
+    s_to_i = 'Transition from Susceptible to Infectious'
+    i_to_r = 'Transition from Infectious to Recovered'
 
 
 class SIR2(SIR):
@@ -158,7 +158,7 @@ class SIR2(SIR):
         """ Handle an infectious state transition
 
         Args:
-            event (:obj:`de_sim.Event`): simulation event that contains the type of transition
+            event (:obj:`~de_sim.event.Event`): simulation event that contains the type of transition
         """
         transition_type = event.message.transition_type
         if transition_type is StateTransitionType.s_to_i:
@@ -206,12 +206,12 @@ class RunSIRs(object):
     def __init__(self, checkpoint_dir):
         self.checkpoint_dir = checkpoint_dir
 
-    def simulate(self, sir_class, time_max, **sir_args):
+    def simulate(self, sir_class, max_time, **sir_args):
         """ Create and run an SIR simulation
 
         Args:
             sir_class (:obj:`type`): a type of SIR class to run
-            time_max (:obj:`float`): simulation end time
+            max_time (:obj:`float`): simulation end time
             sir_args (:obj:`dict`): arguments for an SIR object
         """
 
@@ -232,7 +232,7 @@ class RunSIRs(object):
         simulator.initialize()
 
         # run the simulation
-        event_num = simulator.simulate(time_max).num_events
+        event_num = simulator.simulate(max_time).num_events
         print("Executed {} events.\n".format(event_num))
 
     def print_history(self):
@@ -253,7 +253,7 @@ class RunSIRs(object):
         """ Get the last checkpoint of the last simulation run
 
         Returns:
-            :obj:`Checkpoint`: the last checkpoint of the last simulation run
+            :obj:`~de_sim.checkpoint.Checkpoint`: the last checkpoint of the last simulation run
         """
         access_checkpoints = AccessCheckpoints(self.checkpoint_dir)
         last_checkpoint_time = access_checkpoints.list_checkpoints()[-1]
