@@ -16,25 +16,25 @@ from wc_utils.util.misc import EnhancedDataClass
 
 @dataclass
 class SimulationConfig(EnhancedDataClass):
-    """ Configuration information for a simulation run
+    """ A dataclass that holds configuration information for a simulation run
 
-    - Simulation start time
     - Simulation maximum time
+    - Simulation start time
     - Stop condition
-    - Data directory
+    - Directory for storing simulation metadata
     - Progress bar switch
-    - Profiling switch
-    - Control profiling of changes in heap objects
+    - Performance profiling switch
+    - Configure profiling of heap memory use
 
     Attributes:
-        time_max (:obj:`float`): maximum simulation time
-        time_init (:obj:`float`, optional): time at which a simulation starts
+        max_time (:obj:`float`): maximum simulation time
+        time_init (:obj:`float`, optional): time at which a simulation starts; defaults to 0
         stop_condition (:obj:`function`, optional): if provided, a function that takes one argument,
             the simulation time; a simulation terminates if the function returns `True`
-        output_dir (:obj:`str`, optional): directory for saving metadata; will be created if it does't
-            exist; if not provided, then metatdata should be saved before another simulation is run
-            with the same :obj:`Simulator`
-        progress (:obj:`bool`, optional): if `True`, output a text bar that dynamically reports the
+        output_dir (:obj:`str`, optional): directory for saving metadata; `output_dir` will be created if it does't
+            exist; if not provided, then metadata should be saved before another simulation is run
+            with the same :obj:`~de_sim.simulator.Simulator`
+        progress (:obj:`bool`, optional): if `True`, output a text bar that dynamically reports a
             simulation's progress
         profile (:obj:`bool`, optional): if `True`, output a profile of the simulation's performance
             created by a Python profiler
@@ -43,7 +43,7 @@ class SimulationConfig(EnhancedDataClass):
             cannot be used with `profile` as they run much too slowly
     """
 
-    time_max: float
+    max_time: float
     time_init: float = 0.0
     stop_condition: object = None   # stop_condition must be callable, which is checked below
     output_dir: str = None
@@ -53,14 +53,17 @@ class SimulationConfig(EnhancedDataClass):
     DO_NOT_PICKLE = ['stop_condition']
 
     def __setattr__(self, name, value):
-        """ Validate an attribute when it is changed """
+        """ Validate an attribute in this :obj:`SimulationConfig` when it is changed
+
+        Overrides `__setattr__` in :obj:`EnhancedDataClass` to report errors as :obj:`~de_sim.errors.SimulatorError`\ s
+        """
         try:
             super().__setattr__(name, value)
         except TypeError as e:
             raise SimulatorError(e)
 
     def validate_individual_fields(self):
-        """ Validate constraints other than types in individual fields in a `SimulationConfig` instance
+        """ Validate constraints on individual fields in a :obj:`SimulationConfig` instance
 
         Returns:
             :obj:`None`: if no error is found
@@ -100,11 +103,10 @@ class SimulationConfig(EnhancedDataClass):
     def validate(self):
         """ Validate a `SimulationConfig` instance
 
-        Validation tests that involve multiple fields must be made in this method. Call it after the
-        `SimulationConfig` instance is in a consistent state.
+        Validation tests that involve multiple fields are contained in this method.
 
         Returns:
-            :obj:`None`: if no error is found
+            :obj:`None`: :obj:`None` if no error is found
 
         Raises:
             :obj:`SimulatorError`: if `self` fails validation
@@ -113,8 +115,8 @@ class SimulationConfig(EnhancedDataClass):
         self.validate_individual_fields()
 
         # other validation
-        if self.time_max <= self.time_init:
-            raise SimulatorError(f'time_max ({self.time_max}) must be greater than time_init ({self.time_init})')
+        if self.max_time <= self.time_init:
+            raise SimulatorError(f'max_time ({self.max_time}) must be greater than time_init ({self.time_init})')
 
         if self.profile and 0 < self.object_memory_change_interval:
             raise SimulatorError('profile and object_memory_change_interval cannot both be active, '
@@ -125,13 +127,15 @@ class SimulationConfig(EnhancedDataClass):
 
         Overrides `semantically_equal` in :obj:`EnhancedDataClass`.
         The only attributes that are semantically meaningful to a simulation's predictions are
-        `time_max` and `time_init`. Although they're floats, they are compared exactly because
+        `max_time` and `time_init`. Although they're floats, they are compared exactly because
         they're simulation inputs, not computed outputs.
 
         Args:
             other (:obj:`Object`): other object
 
         Returns:
-            :obj:`bool`: :obj:`True` if `other` is semantically equal to `self`, :obj:`False` otherwise
+            :obj:`bool`: :obj:`True` if `other` is a :obj:`SimulationConfig` that is semantically equal to `self`,
+            :obj:`False` otherwise
         """
-        return self.time_max == other.time_max and self.time_init == other.time_init
+        return (isinstance(other, SimulationConfig) and self.max_time == other.max_time and
+                self.time_init == other.time_init)
