@@ -15,7 +15,7 @@ class NextEvent(de_sim.EventMessage):
 
 
 class TemplatePeriodicSimulationObject(de_sim.SimulationObject):
-    """ Template self-clocking `SimulationObject`
+    """ Template self-clocking :obj:`~de_sim.simulation_object.SimulationObject`
 
     Events occur at time `start_time`, `start_time + period`, `start_time + 2*period`, ...
 
@@ -43,23 +43,31 @@ class TemplatePeriodicSimulationObject(de_sim.SimulationObject):
         self.num_periods += 1
         self.send_event_absolute(next_event_time, self, NextEvent())
 
-    def handle_event(self):
+    def handle_event(self, event):
         """ Handle the periodic event
 
-        Derived classes must override this method and actually handle the event
+        Derived classes which wish to process the event must override this method
+
+        Args:
+            event (:obj:`~de_sim.event.Event`): simulation event; not used
         """
         pass    # pragma: no cover     # must be overridden
 
     def init_before_run(self):
-        # create the initial event
+        """ Schedule the initial event
+        """
         self.schedule_next_event()
 
     def handle_simulation_event(self, event):
-        self.handle_event()
-        self.schedule_next_event()
+        """ Handle the periodic event
 
-    def get_state(self):
-        return ''    # pragma: no cover
+        Args:
+            event (:obj:`~de_sim.event.Event`): the simulation event
+
+        Call `handle_event` and schedule the next event
+        """
+        self.handle_event(event)
+        self.schedule_next_event()
 
     event_handlers = [(NextEvent, handle_simulation_event)]
 
